# Stimela

### [Documentation](https://github.com/SpheMakh/Stimela/wiki)  
### [Installation](https://github.com/SpheMakh/Stimela/wiki/Installation)
### [Tutorials](https://github.com/SpheMakh/Stimela/wiki/Examples)  


This project was initially funded by the [SKA/AWS AstroCompute In The Cloud](https://www.skatelescope.org/ska-aws-astrocompute-call-for-proposals) initiative.
